@@ -40,7 +40,7 @@ namespace pl::core::ast {
         this->m_constant = other.m_constant;
     }
 
-    [[nodiscard]] std::vector<std::shared_ptr<ptrn::Pattern>> ASTNodeArrayVariableDecl::createPatterns(Evaluator *evaluator) const {
+    void ASTNodeArrayVariableDecl::createPatterns(Evaluator *evaluator, std::vector<std::shared_ptr<ptrn::Pattern>> &resultPatterns) const {
         [[maybe_unused]] auto context = evaluator->updateRuntime(this);
 
         auto startOffset = evaluator->getBitwiseReadOffset();
@@ -55,7 +55,7 @@ namespace pl::core::ast {
             if (id == nullptr)
                 err::E0010.throwError("Cannot use void expression as section identifier.", {}, this->getLocation());
 
-            evaluator->pushSectionId(id->getValue().toUnsigned());
+            evaluator->pushSectionId(u64(id->getValue().toUnsigned()));
         } else {
             scopeGuard.release();
         }
@@ -69,29 +69,28 @@ namespace pl::core::ast {
             evaluator->setReadOffset(std::visit(wolv::util::overloaded {
                     [this](const std::string &) -> u64 { err::E0005.throwError("Cannot use string as placement offset.", "Try using a integral value instead.", this->getLocation()); },
                     [this](const std::shared_ptr<ptrn::Pattern>&) -> u64 { err::E0005.throwError("Cannot use string as placement offset.", "Try using a integral value instead.", this->getLocation()); },
-                    [](auto &&offset) -> u64 { return offset; }
+                    [](auto &&offset) -> u64 { return u64(offset); }
             }, offset->getValue()));
         }
 
         if (evaluator->getSectionId() == ptrn::Pattern::PatternLocalSectionId || evaluator->getSectionId() == ptrn::Pattern::HeapSectionId) {
             evaluator->setBitwiseReadOffset(startOffset);
             this->execute(evaluator);
-            return { };
         } else {
             auto type = this->m_type->evaluate(evaluator);
 
-            std::shared_ptr<ptrn::Pattern> pattern;
+            auto &pattern = resultPatterns.emplace_back();
             if (auto builtinType = dynamic_cast<ASTNodeBuiltinType *>(type.get()); builtinType != nullptr && builtinType->getType() != Token::ValueType::CustomType)
-                pattern = createStaticArray(evaluator);
+                createStaticArray(evaluator, pattern);
             else {
                 bool isStaticType = false;
                 if (auto attributable = dynamic_cast<Attributable *>(type.get()))
                     isStaticType = attributable->hasAttribute("static", false);
 
                 if (isStaticType)
-                    pattern = createStaticArray(evaluator);
+                    createStaticArray(evaluator, pattern);
                 else
-                    pattern = createDynamicArray(evaluator);
+                    createDynamicArray(evaluator, pattern);
             }
 
             pattern->setSection(evaluator->getSectionId());
@@ -104,10 +103,8 @@ namespace pl::core::ast {
 
             if (this->m_placementSection != nullptr && !evaluator->isGlobalScope()) {
                 evaluator->addPattern(std::move(pattern));
-                return {};
+                resultPatterns.pop_back();
             }
-
-            return hlp::moveToVector<std::shared_ptr<ptrn::Pattern>>(std::move(pattern));
         }
     }
 
@@ -125,7 +122,7 @@ namespace pl::core::ast {
         auto entryCount = std::visit(wolv::util::overloaded {
                 [this](const std::string &) -> i128 { err::E0006.throwError("Cannot use string to index array.", "Try using an integral type instead.", this->getLocation()); },
                 [this](const std::shared_ptr<ptrn::Pattern> &pattern) -> i128 {err::E0006.throwError(fmt::format("Cannot use custom type '{}' to index array.", pattern->getTypeName()), "Try using an integral type instead.", this->getLocation()); },
-                [](auto &&size) -> i128 { return size; }
+                [](auto &&size) -> i128 { return i128(size); }
         }, sizeLiteral->getValue());
 
         u64 section = 0;
@@ -135,12 +132,12 @@ namespace pl::core::ast {
             if (sectionLiteral == nullptr)
                 err::E0002.throwError("Cannot use void expression as section identifier.", {}, this->getLocation());
 
-            section = sectionLiteral->getValue().toUnsigned();
+            section = u64(sectionLiteral->getValue().toUnsigned());
         } else {
             section = evaluator->getSectionId();
         }
 
-        evaluator->createArrayVariable(this->m_name, this->m_type.get(), entryCount, section, this->m_constant);
+        evaluator->createArrayVariable(this->m_name, this->m_type.get(), size_t(entryCount), section, this->m_constant);
 
         if (this->m_placementOffset != nullptr) {
             const auto placementNode = this->m_placementOffset->evaluate(evaluator);
@@ -148,18 +145,19 @@ namespace pl::core::ast {
             if (offsetLiteral == nullptr)
                 err::E0002.throwError("Void expression used in placement expression.", { }, this->getLocation());
 
-            evaluator->setVariableAddress(this->getName(), offsetLiteral->getValue().toUnsigned(), section);
+            evaluator->setVariableAddress(this->getName(), u64(offsetLiteral->getValue().toUnsigned()), section);
         }
 
         return std::nullopt;
     }
 
 
-    std::unique_ptr<ptrn::Pattern> ASTNodeArrayVariableDecl::createStaticArray(Evaluator *evaluator) const {
+    void ASTNodeArrayVariableDecl::createStaticArray(Evaluator *evaluator, std::shared_ptr<ptrn::Pattern> &outputPattern) const {
         evaluator->alignToByte();
         auto startOffset = evaluator->getReadOffset();
 
-        auto templatePatterns = this->m_type->createPatterns(evaluator);
+        std::vector<std::shared_ptr<ptrn::Pattern>> templatePatterns;
+        this->m_type->createPatterns(evaluator, templatePatterns);
         if (templatePatterns.empty())
             err::E0005.throwError("'auto' can only be used with parameters.", { }, this->getLocation());
 
@@ -178,7 +176,7 @@ namespace pl::core::ast {
                 entryCount = std::visit(wolv::util::overloaded {
                         [this](const std::string &) -> i128 { err::E0006.throwError("Cannot use string to index array.", "Try using an integral type instead.", this->getLocation()); },
                         [this](const std::shared_ptr<ptrn::Pattern> &pattern) -> i128 {err::E0006.throwError(fmt::format("Cannot use custom type '{}' to index array.", pattern->getTypeName()), "Try using an integral type instead.", this->getLocation()); },
-                        [](auto &&size) -> i128 { return size; }
+                        [](auto &&size) -> i128 { return i128(size); }
                 }, literal->getValue());
             } else if (auto whileStatement = dynamic_cast<ASTNodeWhileStatement *>(sizeNode.get())) {
                 while (whileStatement->evaluateCondition(evaluator)) {
@@ -219,7 +217,6 @@ namespace pl::core::ast {
             }
         }
 
-        std::unique_ptr<ptrn::Pattern> outputPattern;
         if (dynamic_cast<ptrn::PatternPadding *>(templatePattern.get())) {
             outputPattern = std::make_unique<ptrn::PatternPadding>(evaluator, startOffset, 0, getLocation().line);
         } else if (dynamic_cast<ptrn::PatternCharacter *>(templatePattern.get())) {
@@ -228,7 +225,7 @@ namespace pl::core::ast {
             outputPattern = std::make_unique<ptrn::PatternWideString>(evaluator, startOffset, 0, getLocation().line);
         } else {
             auto arrayPattern = std::make_unique<ptrn::PatternArrayStatic>(evaluator, startOffset, 0, getLocation().line);
-            arrayPattern->setEntries(templatePattern->clone(), entryCount);
+            arrayPattern->setEntries(templatePattern->clone(), size_t(entryCount));
             arrayPattern->setSection(templatePattern->getSection());
             outputPattern = std::move(arrayPattern);
         }
@@ -237,7 +234,7 @@ namespace pl::core::ast {
         if (templatePattern->hasOverriddenEndian())
             outputPattern->setEndian(templatePattern->getEndian());
         outputPattern->setTypeName(templatePattern->getTypeName());
-        outputPattern->setSize(templatePattern->getSize() * entryCount);
+        outputPattern->setSize(size_t(templatePattern->getSize() * entryCount));
         if (evaluator->isReadOrderReversed())
             outputPattern->setAbsoluteOffset(evaluator->getReadOffset());
         outputPattern->setSection(templatePattern->getSection());
@@ -247,11 +244,9 @@ namespace pl::core::ast {
         if (outputPattern->getSection() == ptrn::Pattern::MainSectionId)
             if ((evaluator->getReadOffset() - evaluator->getDataBaseAddress()) > (evaluator->getDataSize() + 1))
                 err::E0004.throwError("Array expanded past end of the data.", { }, this->getLocation());
-
-        return outputPattern;
     }
 
-    std::unique_ptr<ptrn::Pattern> ASTNodeArrayVariableDecl::createDynamicArray(Evaluator *evaluator) const {
+    void ASTNodeArrayVariableDecl::createDynamicArray(Evaluator *evaluator, std::shared_ptr<ptrn::Pattern> &resultPattern) const {
         auto startArrayIndex = evaluator->getCurrentArrayIndex();
         ON_SCOPE_EXIT {
         if (startArrayIndex.has_value())
@@ -270,6 +265,16 @@ namespace pl::core::ast {
         size_t size    = 0;
         u64 entryIndex = 0;
 
+        ON_SCOPE_EXIT {
+            if (arrayPattern->getEntryCount() > 0)
+                arrayPattern->setTypeName(arrayPattern->getEntry(0)->getTypeName());
+
+            arrayPattern->setEntries(entries);
+            arrayPattern->setSize(size);
+
+            resultPattern = std::move(arrayPattern);
+        };
+
         auto addEntries = [&](std::vector<std::shared_ptr<ptrn::Pattern>> &&patterns) {
             for (auto &pattern : patterns) {
                 pattern->setArrayIndex(entryIndex);
@@ -300,7 +305,7 @@ namespace pl::core::ast {
                 auto entryCount = std::visit(wolv::util::overloaded {
                         [this](const std::string &) -> u128 { err::E0006.throwError("Cannot use string to index array.", "Try using an integral type instead.", this->getLocation()); },
                         [this](const std::shared_ptr<ptrn::Pattern> &pattern) -> u128 {err::E0006.throwError(fmt::format("Cannot use custom type '{}' to index array.", pattern->getTypeName()), "Try using an integral type instead.", this->getLocation()); },
-                        [](auto &&size) -> u128 { return size; }
+                        [](auto &&size) -> u128 { return u128(size); }
                 }, literal->getValue());
 
                 auto limit = evaluator->getArrayLimit();
@@ -312,7 +317,8 @@ namespace pl::core::ast {
 
                     evaluator->setCurrentArrayIndex(i);
 
-                    auto patterns = this->m_type->createPatterns(evaluator);
+                    std::vector<std::shared_ptr<ptrn::Pattern>> patterns;
+                    this->m_type->createPatterns(evaluator, patterns);
                     size_t patternCount = patterns.size();
 
                     if (arrayPattern->getSection() == ptrn::Pattern::MainSectionId)
@@ -342,7 +348,8 @@ namespace pl::core::ast {
 
                     evaluator->setCurrentControlFlowStatement(ControlFlowStatement::None);
 
-                    auto patterns       = this->m_type->createPatterns(evaluator);
+                    std::vector<std::shared_ptr<ptrn::Pattern>> patterns;
+                    this->m_type->createPatterns(evaluator, patterns);
                     size_t patternCount = patterns.size();
 
                     if (arrayPattern->getSection() == ptrn::Pattern::MainSectionId)
@@ -374,7 +381,8 @@ namespace pl::core::ast {
 
                 evaluator->setCurrentControlFlowStatement(ControlFlowStatement::None);
 
-                auto patterns = this->m_type->createPatterns(evaluator);
+                std::vector<std::shared_ptr<ptrn::Pattern>> patterns;
+                this->m_type->createPatterns(evaluator, patterns);
 
                 for (auto &pattern : patterns) {
                     std::vector<u8> buffer(pattern->getSize());
@@ -415,14 +423,5 @@ namespace pl::core::ast {
                 if (reachedEnd) break;
             }
         }
-
-
-        if (arrayPattern->getEntryCount() > 0)
-            arrayPattern->setTypeName(arrayPattern->getEntry(0)->getTypeName());
-
-        arrayPattern->setEntries(entries);
-        arrayPattern->setSize(size);
-
-        return arrayPattern;
     }
 }
\ No newline at end of file
