@@ -24,8 +24,8 @@ namespace hex {
 
         static void removeWorkspace(const std::string &name);
 
-        static const auto& getWorkspaces() { return *s_workspaces; }
-        static const auto& getCurrentWorkspace() { return s_currentWorkspace; }
+        static const std::map<std::string, Workspace>& getWorkspaces();
+        static const std::map<std::string, Workspace>::iterator& getCurrentWorkspace();
 
         static void reset();
         static void reload();
@@ -34,9 +34,6 @@ namespace hex {
 
     private:
         WorkspaceManager() = default;
-
-        static AutoReset<std::map<std::string, Workspace>> s_workspaces;
-        static decltype(s_workspaces)::Type::iterator s_currentWorkspace, s_previousWorkspace, s_workspaceToRemove;
     };
 
 }
\ No newline at end of file
